#!/usr/bin/env python
#
# Copyright (c) 2016-2017, Parallels International GmbH
#
# This file is part of disp-helper. It's free software; you can redistribute
# it and/or modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the License,
# or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#
# Our contact details: Parallels International GmbH, Vordergasse 59, 8200
# Schaffhausen, Switzerland.
#

import os
import sys
import shutil
import subprocess
from infra_cep_helper import CEPCollecting


class ManagePy(CEPCollecting):

    def service_active(self, service):
        """Return True if service is running/waiting"""
        cmd = '/bin/systemctl status %s' % service
        proc = subprocess.Popen(cmd, shell=True,stdout=subprocess.PIPE)
        stdout_list = proc.communicate()[0].split('\n')
        for line in stdout_list:
            if 'Active:' in line:
                if '(running)' in line:
                    return True
        return False

    def collect_backend_output(self):
        home_folder = os.environ['HOME'] = "/usr/libexec/vstorage-ui-backend"
        ld_path = os.environ['LD_LIBRARY_PATH'] = "/opt/rh/rh-python34/root/usr/lib64 "
        user = os.environ['USER'] = "vstoradmin "
        new_path = os.environ['PATH'] = "/usr/libexec/vstorage-ui-backend/venv/bin:/opt/rh/rh-python34/root/usr/bin:/usr/local/bin:/bin:/usr/bin:/usr/local/sbin:/usr/sbin "
        backend_conf = 'UI_BACKEND_CONFIG=/usr/libexec/vstorage-ui-backend/etc/backend.cfg '
        venv = os.environ['VIRTUAL_ENV'] = "/usr/libexec/vstorage-ui-backend/venv/"
        cmd = 'sudo -E -u ' + user + backend_conf + 'PATH=' + new_path + 'LD_LIBRARY_PATH='+ ld_path + venv + 'bin/python ' + home_folder  + '/manage.py make_report'
        proc = subprocess.Popen(cmd, shell=True,stdout=subprocess.PIPE, stderr=subprocess.PIPE)
        proc.communicate()
        if proc.returncode != 0:
           print "Command [%s] reported an error" % cmd
           sys.exit(1)
        else:
           dstdir = '/vz/tmp/cep/output/final'
           shutil.copy('/var/cache/cep/cluster_report.tar', dstdir)

    def fill_results(self):
        if self.service_active('postgresql'):
           o = self.collect_backend_output()
        else:
           print "postgresql not running, nothing to collect"
           sys.exit(1)

def main():
    o = ManagePy()
    o.run()

if __name__ == "__main__":
    main()
