#!/usr/bin/env python
#
# Copyright (c) 2016-2017, Parallels International GmbH
#
# This file is part of disp-helper. It's free software; you can redistribute
# it and/or modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the License,
# or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#
# Our contact details: Parallels International GmbH, Vordergasse 59, 8200
# Schaffhausen, Switzerland.
#

from infra_cep_helper import CEPCollecting
from lxml import etree
import os
import json

class Hardware(CEPCollecting):
    def fill_results(self):
	self.result["Sscsi_Devices"] = self.get_lsscsi_output()
	self.result["Numa_Values"] = self.get_numa_output()
	if os.path.exists("/usr/sbin/lshw"):
	    cmd = "/usr/sbin/lshw -json"
	    out = self.execute_shell(cmd)
            hardwares = json.loads(out)
	    self.result["LSHW_Devices"] = hardwares
	if os.path.exists("/usr/sbin/dmidecode"):
	    dmidecode = {}
	    for s in ['bios-vendor', 'bios-version', 'bios-release-date', 'system-manufacturer', 'system-product-name',
			'system-version', 'system-serial-number', 'system-uuid', 'baseboard-manufacturer', 'baseboard-product-name',
			'baseboard-version', 'baseboard-serial-number', 'baseboard-asset-tag', 'chassis-manufacturer',
			'chassis-type', 'chassis-version', 'chassis-serial-number', 'chassis-asset-tag', 'processor-family',
			'processor-manufacturer', 'processor-version', 'processor-frequency']:
		try:
		    dmidecode[s] = self.execute_shell("dmidecode -s " + s).strip()
		except:
		    pass
	    self.result["dmidecode"] = dmidecode

    def get_numa_output(self):
        value = ""
        key = ""
        numa_hw = {}

        try:
            out = self.execute_shell("/usr/bin/numactl --hardware")
            for l in out.splitlines():
                if ":" in l:
                    if key:
                        numa_hw[key] = value
                    l_array = l.strip().split(":")
                    key = l_array[0].strip()
                    value = ":".join(l_array[1:]).strip()
                else:
                    value += " " + l.strip()
            if key:
                numa_hw[key] = value.strip()
        except:
            return {}
        return numa_hw

    def get_lsscsi_output(self):
        value = ""
        key = ""
        lsscsi_hw = {}

        try:
            out = self.execute_shell("/usr/bin/lsscsi -sdx")
            for l in out.splitlines():
                if ":" in l:
                    if key:
                        lsscsi_hw[key] = value
                    l_array = l.strip().split(" ")
                    key = l_array[0].strip()
                    value = ":".join(l_array[1:]).strip()
                else:
                    value += " " + l.strip()
            if key:
                lsscsi_hw[key] = value.strip()
        except:
            return {}
        return lsscsi_hw


def main():
    o = Hardware()
    o.run()


if __name__ == "__main__":
    main()
