#!/usr/bin/env python
#
# Copyright (c) 2016-2017, Parallels International GmbH
#
# This file is part of disp-helper. It's free software; you can redistribute
# it and/or modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the License,
# or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#
# Our contact details: Parallels International GmbH, Vordergasse 59, 8200
# Schaffhausen, Switzerland.
#

import signal
import sys
import json
import os
from datetime import datetime
from subprocess import Popen, PIPE
from abc import ABCMeta, abstractmethod


def sigterm_handler(_signo, _stack_frame):
    # Raises SystemExit(0):
    print "Killed, oh no!"
    sys.exit(0)


class CEPCollecting(object):
    __metaclass__ = ABCMeta

    def execute_shell(self, command):
        p = Popen(command, shell=True, stdout=PIPE, stderr=PIPE)
        (out, err) = p.communicate()
        return out

    def prepare_tags(self, d):
        if isinstance(d, dict):
            for key in d.keys():
                self.prepare_tags(d[key])
                new_tag = key.replace(" ", "")
                if key[0].isdigit():
                    new_tag = "_" + new_tag
                d[new_tag] = d.pop(key)
        else:
            return

    def prepare(self):
        self.label = self.__class__.__name__
        if len(sys.argv) != 3:
            raise ValueError("Bad script argument")
            sys.exit(1)
        signal.signal(signal.SIGTERM, sigterm_handler)
        self.label = os.path.splitext(os.path.basename(sys.argv[0]))[0]
        self.result = {}

    def serialize(self):
        t = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
        self.result["CollectDate"] = t
        with open(os.path.join(sys.argv[1], self.label + ".json"),
                  "w") as f:
            json.dump(self.result, f)

    @abstractmethod
    def fill_results(self):
        pass

    def run(self):
        try:
            self.prepare()
            self.fill_results()
            self.serialize()
        except Exception as e:
            print e
            d = "/vz/tmp/cep/"
            if os.path.isdir(sys.argv[1]):
                d = sys.argv[1]

            p = os.path.join(d, self.label + "-fail.log")
            try:
                with open(p, 'a'):
                    os.utime(p, None)
            except:
                pass
