#!/usr/bin/env python
#
# Copyright (c) 2016-2017, Parallels International GmbH
#
# This file is part of disp-helper. It's free software; you can redistribute
# it and/or modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the License,
# or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#
# Our contact details: Parallels International GmbH, Vordergasse 59, 8200
# Schaffhausen, Switzerland.
#

import time
import libvirt
from infra_cep_helper import CEPCollecting


class LibvirtStats(CEPCollecting):
    def get_stats(self):
        r = dict()
        r["Capabilities"] = self.conn.getCapabilities()
        r["CPUStats"] = self.conn.getCPUStats(-1)
        r["CPUMap"] = self.conn.getCPUMap()
        r["DomainStats"] = [(d[0].XMLDesc(), d[1:])
                            for d in self.conn.getAllDomainStats()]
        r["Sysinfo"] = self.conn.getSysinfo()
        r["MemoryStats"] = self.conn.getMemoryStats(-1)
        r["Networks"] = [d.XMLDesc() for d in self.conn.listAllNetworks()]
        r["StoragePools"] = [d.XMLDesc() for d
                             in self.conn.listAllStoragePools()]
        r["Domains"] = [d.XMLDesc() for d in self.conn.listAllDomains()]
        r["NWFilters"] = [d.XMLDesc() for d in self.conn.listAllNWFilters()]
        r["Interfaces"] = [d.XMLDesc() for d in self.conn.listAllInterfaces()]
        r["Devices"] = [d.XMLDesc() for d in self.conn.listAllDevices()]
        return r

    def fill_results(self):
        retries = 0
        succeed = False
        fail_reason = "Unknown reason"
        while not succeed and retries < 4:
            try:
                self.conn = libvirt.openReadOnly(None)
                if self.conn is None:
                    raise Exception("Unable to connect to libvirt")
                self.result["LibvirtStats"] = self.get_stats()
                succeed = True
            except Exception as e:
                retries += 1
                time.sleep(60 * 2 * retries)
                succeed = False
                fail_reason = str(e)
        if not succeed:
            raise StandardError("Unable to collect libvirt stats info: " + fail_reason)


def main():
    o = LibvirtStats()
    o.run()


if __name__ == "__main__":
    main()
